/**
 * APITable <https://github.com/apitable/apitable>
 * Copyright (C) 2022 APITable Ltd. <https://apitable.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { IDeniedField } from '../core';
import { Field } from '../model/field';
import { Datasheet } from '../model';
/**
 * Get information about a specified field.
 * Rerendering is triggered when a field property changes.
 *
 * If no ID is passed in, undefined is returned.
 *
 * @param fieldId The ID for this field.
 * @returns
 *
 * ### Example
 * ```js
 * import { useField } from '@apitable/widget-sdk';
 *
 * // show field name
 * function FieldName() {
 *   const field = useField('fldXXXXXXX');
 *   return <p>{field.name}</p>
 * }
 * ```
 *
 */
export declare function useField(fieldId: string | undefined): Field | undefined;
/**
 * ## Support for loading the corresponding datasheet data field.
 *
 * @param datasheet Datasheet instance, by {@link useDatasheet} get.
 * @param fieldId The ID for this field
 * @returns
 *
 *
 * ### Example
 * ```js
 * import { useField, useDatasheet } from '@apitable/widget-sdk';
 *
 * // show field name corresponding to the datasheetId(dstXXXXXXXX) datasheet
 * function FieldName() {
 *   const datasheet = useDatasheet('dstXXXXXXXX');
 *   const field = useField(datasheet, 'fldXXXXXXX');
 *   return <p>{field.name}</p>
 * }
 *
 * ```
 */
export declare function useField(datasheet: Datasheet | undefined, fieldId: string | undefined): Field | undefined;
/** @internal */
export declare function createDeniedField(): IDeniedField;
//# sourceMappingURL=use_field.d.ts.map