import { IWidgetContext } from '../interface';
import { Datasheet } from './datasheet';
export declare class Space {
    private wCtx;
    /**
     * @hidden
     */
    constructor(wCtx: IWidgetContext);
    /**
     * The unique ID of the space.
     * @returns
     *
     * #### Example
     * ```js
     * console.log(space.id); // => 'spcxxxxxx'
     * ```
     */
    get id(): string | undefined;
    /**
     * The name of the space.
     * @returns
     *
     * #### Example
     * ```js
     * console.log(space.name); // => 'Test Space'
     * ```
     */
    get name(): string | undefined;
    /**
     * Get the active datasheet for the space.
     *
     * @returns
     *
     * #### Example
     * ```js
     * const activeDatasheet = await space.getActiveDatasheetAsync();
     * console.log(activeDatasheet); // => Datasheet
     * ```
     */
    getActiveDatasheetAsync(): Promise<Datasheet>;
    /**
     * Get the specified datasheet in the space.
     *
     * @param datasheetId The ID of the datasheet.
     * @returns
     *
     * #### Example
     * ```js
     * const datasheet = await space.getDatasheetAsync('dstxxxxxx');
     * console.log(datasheet); // => Datasheet
     * ```
     */
    getDatasheetAsync(datasheetId: string): Promise<Datasheet>;
}
//# sourceMappingURL=space.d.ts.map